@@ -100,7 +100,7 @@ class Client:
             self.base_url = base_url
             
         def status(self, job_id):
-            url = '{}testrq_getmyprocstatus/{}/'.format(self.base_url, job_id)
+            url = '{}getmyprocstatus/{}/'.format(self.base_url, job_id)
             headers = {'Authorization': 'Token {}'.format(self.api_token)}
             results = requests.get(url, headers=headers)
             return(results.json())
@@ -125,6 +125,7 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
+            provider_id = str(provider_id)
             url = '{}filelist/{}'.format(self.base_url, provider_id)
             headers = {'Authorization': 'Token {}'.format(self.api_token)}
             sheet = requests.get(url, headers=headers)
@@ -159,15 +160,23 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
-            url = '{}fileget/{}/{}/?sub_sheet={}&skip_rows={}'.format(self.base_url, provider_id, sheet_id, sub_sheet, skip_rows)
-            headers = {'Authorization': 'Token {}'.format(self.api_token)}
-            sheet = requests.get(url, headers=headers)
+            provider_id = str(provider_id)
+            sheet_id = str(sheet_id)
+            url = '{}fileget/'.format(self.base_url)
+            data = {'provider_id':provider_id, 'sheet_name':sheet_id, 'sub_sheet':sub_sheet, 'skip_rows':skip_rows}
+            data = json.dumps(data)
+            headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
+            sheet = requests.post(url, headers=headers, data=data)
+            
             if sheet.status_code == 200:
                 results = sheet.json()
                 while True:
                     procstatus = self.status(results['id'])
                     if procstatus['status'] == 'finished':
-                        return(pd.read_json(procstatus['result']))
+                        try:
+                            return(pd.read_json(procstatus['result']))
+                        except:
+                            return("Error loading data:  {}".format(procstatus))
                     elif procstatus['status'] == 'failed':
                         return(procstatus)
                     time.sleep(1)
@@ -204,9 +213,13 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
-            url = '{}fileinfo/{}/{}'.format(self.base_url, provider_id, sheet_id)
-            headers = {'Authorization': 'Token {}'.format(self.api_token)}
-            sheet = requests.get(url, headers=headers)
+            provider_id = str(provider_id)
+            sheet_id = str(sheet_id)
+            url = '{}fileinfo/'.format(self.base_url)
+            data = {'provider_id':provider_id, 'sheet_name':sheet_id}
+            data = json.dumps(data)
+            headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
+            sheet = requests.post(url, headers=headers, data=data)
             if sheet.status_code == 200:
                 return(sheet.json())
             else:
@@ -238,15 +251,22 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
-            url = '{}fileupdate/{}/{}/?sub_sheet={}'.format(self.base_url, provider_id, sheet_id, sub_sheet)
+            provider_id = str(provider_id)
+            sheet_id = str(sheet_id)
+            url = '{}fileupdate/'.format(self.base_url)
+            data = {'provider_id':provider_id, 'sheet_name':sheet_id, 'sub_sheet':sub_sheet, 'data':df_to_json(data.fillna(""))}
+            data = json.dumps(data)
             headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
-            sheet = requests.post(url, headers=headers, data=df_to_json(data.fillna("")))
+            sheet = requests.post(url, headers=headers, data=data)
             if sheet.status_code == 200:
                 results = sheet.json()
                 while True:
                     procstatus = self.status(results['id'])
                     if procstatus['status'] == 'finished':
-                        return(procstatus['result'])
+                        try:
+                            return(procstatus['result'])
+                        except:
+                            return("Error loading data:  {}".format(procstatus))
                     elif procstatus['status'] == 'failed':
                         return(procstatus)
                     time.sleep(1)
@@ -284,17 +304,24 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
+            provider_id = str(provider_id)
+            sheet_name = str(sheet_name)
             if ((sheet_type.lower() == 'sheet') & (folder_path != '0')):
                 raise RuntimeError("folder_path cannot be set with sheet_type=sheet")
-            url = '{}filecreate/{}/{}/?sub_sheet={}&sheet_type={}&folder_id={}'.format(self.base_url, provider_id, sheet_name, sub_sheet, sheet_type, folder_path)
+            url = '{}filecreate/'.format(self.base_url)
+            data = {'provider_id':provider_id, 'sheet_name':sheet_name, 'sub_sheet':sub_sheet, 'sheet_type':sheet_type, 'folder_path':folder_path, 'data':df_to_json(data.fillna(""))}
+            data = json.dumps(data)
             headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
-            sheet = requests.post(url, headers=headers, data=df_to_json(data.fillna("")))
+            sheet = requests.post(url, headers=headers, data=data)
             if sheet.status_code == 200:
                 results = sheet.json()
                 while True:
                     procstatus = self.status(results['id'])
                     if procstatus['status'] == 'finished':
-                        return(procstatus['result'])
+                        try:
+                            return(procstatus['result'])
+                        except:
+                            return("Error loading data:  {}".format(procstatus))                    
                     elif procstatus['status'] == 'failed':
                         return(procstatus)
                     time.sleep(1)
@@ -322,9 +349,13 @@ class Client:
             RuntimeError
                 If the API returns anything other than Status 200
             """
-            url = '{}filedelete/{}/{}'.format(self.base_url, provider_id, sheet_id)
-            headers = {'Authorization': 'Token {}'.format(self.api_token)}
-            sheet = requests.get(url, headers=headers)
+            provider_id = str(provider_id)
+            sheet_id = str(sheet_id)
+            url = '{}filedelete/'.format(self.base_url)
+            data = {'provider_id':provider_id, 'sheet_name':sheet_id}
+            data = json.dumps(data)
+            headers = {'Authorization': 'Token {}'.format(self.api_token), 'Content-Type':'application/json'}
+            sheet = requests.post(url, headers=headers, data=data)
             if sheet.status_code == 200:
                 return(sheet.json())
             else:
